@@ -1,18 +1,19 @@
-from dataclasses import field
 from typing import List, Optional
 
-from ome_types.dataclasses import AUTO_SEQUENCE, ome_dataclass
+from pydantic import Field
+
+from ome_types._base_type import OMEType
 
 from .annotation_ref import AnnotationRef
 from .simple_types import AnnotationID, ExperimenterID
 
 
-@ome_dataclass
-class Annotation:
+class Annotation(OMEType):
     """An annotation from which all others are ultimately derived.
 
     Parameters
     ----------
+    id : AnnotationID
     annotation_ref : AnnotationRef, optional
     annotator : ExperimenterID, optional
         The Annotator is the person who attached this annotation. e.g. If
@@ -20,15 +21,14 @@ class Annotation:
         the Annotator.
     description : str, optional
         A description for the annotation.
-    id : AnnotationID
     namespace : str, optional
         We recommend the inclusion of a namespace for annotations you define.
         If it is absent then we assume the annotation is to use our (OME's)
         default interpretation for this type.
     """
 
-    annotation_ref: List[AnnotationRef] = field(default_factory=list)
+    id: AnnotationID
+    annotation_ref: List[AnnotationRef] = Field(default_factory=list)
     annotator: Optional[ExperimenterID] = None
     description: Optional[str] = None
-    id: AnnotationID = AUTO_SEQUENCE  # type: ignore
     namespace: Optional[str] = None
