@@ -1,5 +1,7 @@
 from typing import Optional
 
+from typing_extensions import Literal
+
 from ome_types._base_type import OMEType
 
 from .light_source import LightSource
@@ -35,4 +37,5 @@ class GenericExcitationSource(LightSource, OMEType):
         The serial number of the component.
     """
 
+    kind: Literal["generic_excitation_source"] = "generic_excitation_source"
     map: Optional[Map] = None
